ImageThumbnailCacher class abstract

Interface for caching thumbnails

Constructors

ImageThumbnailCacher()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read(String id) → Future<PageToImage?>
Read from cache
toString() → String
A string representation of this object.
inherited
write({required String id, required PageToImage map}) → Future<bool>
Write to cache

Operators

operator ==(Object other) → bool
The equality operator.
inherited